@@ -1,5 +1,5 @@
 from django.core.management.base import BaseCommand
-from captcha.models import get_safe_now
+from django.utils import timezone
 import sys
 
 
@@ -8,8 +8,11 @@ class Command(BaseCommand):
 
     def handle(self, **options):
         from captcha.models import CaptchaStore
-        verbose = int(options.get('verbosity'))
-        expired_keys = CaptchaStore.objects.filter(expiration__lte=get_safe_now()).count()
+
+        verbose = int(options.get("verbosity"))
+        expired_keys = CaptchaStore.objects.filter(
+            expiration__lte=timezone.now()
+        ).count()
         if verbose >= 1:
             print("Currently %d expired hashkeys" % expired_keys)
         try:
