@@ -1,22 +1,30 @@
-from captcha.conf import settings as captcha_settings
-from django.db import models
-from django.utils import timezone
-from django.utils.encoding import python_2_unicode_compatible
-from django.utils.encoding import smart_text
 import datetime
 import hashlib
 import logging
 import random
 import time
 
+import django
+from django.db import models
+from django.utils import timezone
+
+from captcha.conf import settings as captcha_settings
+from six import python_2_unicode_compatible
+
+
+if django.VERSION >= (3, 0):
+    from django.utils.encoding import smart_str as smart_text
+else:
+    from django.utils.encoding import smart_text
+
 
 # Heavily based on session key generation in Django
 # Use the system (hardware-based) random number generator if it exists.
-if hasattr(random, 'SystemRandom'):
+if hasattr(random, "SystemRandom"):
     randrange = random.SystemRandom().randrange
 else:
     randrange = random.randrange
-MAX_RANDOM_KEY = 18446744073709551616     # 2 << 63
+MAX_RANDOM_KEY = 18446744073709551616  # 2 << 63
 
 logger = logging.getLogger(__name__)
 
@@ -31,16 +39,18 @@ class CaptchaStore(models.Model):
     def save(self, *args, **kwargs):
         self.response = self.response.lower()
         if not self.expiration:
-            self.expiration = timezone.now() + datetime.timedelta(minutes=int(captcha_settings.CAPTCHA_TIMEOUT))
+            self.expiration = timezone.now() + datetime.timedelta(
+                minutes=int(captcha_settings.CAPTCHA_TIMEOUT)
+            )
         if not self.hashkey:
             key_ = (
-                smart_text(randrange(0, MAX_RANDOM_KEY)) +
-                smart_text(time.time()) +
-                smart_text(self.challenge, errors='ignore') +
-                smart_text(self.response, errors='ignore')
-            ).encode('utf8')
+                smart_text(randrange(0, MAX_RANDOM_KEY))
+                + smart_text(time.time())
+                + smart_text(self.challenge, errors="ignore")
+                + smart_text(self.response, errors="ignore")
+            ).encode("utf8")
             self.hashkey = hashlib.sha1(key_).hexdigest()
-            del(key_)
+            del key_
         super(CaptchaStore, self).save(*args, **kwargs)
 
     def __str__(self):
@@ -48,6 +58,7 @@ class CaptchaStore(models.Model):
 
     def remove_expired(cls):
         cls.objects.filter(expiration__lte=timezone.now()).delete()
+
     remove_expired = classmethod(remove_expired)
 
     @classmethod
@@ -67,8 +78,12 @@ class CaptchaStore(models.Model):
             return cls.generate_key()
 
         # Pick up a random item from pool
-        minimum_expiration = timezone.now() + datetime.timedelta(minutes=int(captcha_settings.CAPTCHA_GET_FROM_POOL_TIMEOUT))
-        store = cls.objects.filter(expiration__gt=minimum_expiration).order_by('?').first()
+        minimum_expiration = timezone.now() + datetime.timedelta(
+            minutes=int(captcha_settings.CAPTCHA_GET_FROM_POOL_TIMEOUT)
+        )
+        store = (
+            cls.objects.filter(expiration__gt=minimum_expiration).order_by("?").first()
+        )
 
         return (store and store.hashkey) or fallback()
 
